<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/admin_group.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class AdminGroup extends TeamServer {
    private static $instance = NULL;

    public function __construct() {
        parent::__construct();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }
        return self::$instance;
    }

    public function startGroupAdmin() {
        switch ( $this->action ) {
            case "newgroup":
                self::teamGroupForm();
                break;
            case "editgroup":
                self::teamGroupForm( get( 'tgroup_id', FILTER_VALIDATE_INT ) );
                break;
            case "deletegroup":
                if ( get('tgroup_id', FILTER_VALIDATE_INT ) ) {
                    self::delGroup( get( 'tgroup_id', FILTER_VALIDATE_INT ) );
                }
                redirect( clean_request( '', ['action', 'tgroup_id'], FALSE ) );
                break;
            case "publishgroup":
                if ( get('tgroup_id', FILTER_VALIDATE_INT ) ) {
                    self::groupMod( 1, get( 'tgroup_id' ) );
                }
                addnotice( 'success', self::$locale['TEAM_E13'] );
                redirect( clean_request( '', ['action', 'tgroup_id'], FALSE ) );
                break;
            case "unpublishgroup":
                if ( get('tgroup_id', FILTER_VALIDATE_INT ) ) {
                    self::groupMod( 0, get( 'tgroup_id' ) );
                }
                addnotice( 'success', self::$locale['TEAM_E14'] );
                redirect( clean_request( '', ['action', 'tgroup_id'], FALSE ) );
                break;
            default:
                self::groupList();
                break;
        }
    }

    private function editTeamGroup( $groupid = NULL ) {
        if ( !empty( $groupid ) && isnum( $groupid ) ) {
            $result = dbquery( $this->sqlTeam->getTeamGroupQuery( ['condition' => "tgroup_id = :tgroupid"] ), [':tgroupid' => $groupid] );
            if ( dbrows( $result ) ) {
                self::$def_teamgroup = dbarray( $result );
            } else {
                redirect( clean_request( '', ['action'], FALSE ) );
            }
        }
    }

    private function teamGroupForm( $groupid = NULL) {
        if ( !empty( $groupid ) ) {
            self::editTeamGroup( $groupid );
        }

        if ( check_post( 'save_group' ) ) {
            $inputData = [
                'tgroup_id'       => sanitizer( 'tgroup_id', '', 'tgroup_id' ),
                'tgroup_parent'   => sanitizer( 'tgroup_parent', 0, 'tgroup_parent' ),
                'tgroup_name'     => sanitizer( 'tgroup_name', '', 'tgroup_name' ),
                'tgroup_pic'      => sanitizer( 'tgroup_pic', '', 'tgroup_pic' ),
                'tgroup_status'   => sanitizer( 'tgroup_status', 0, 'tgroup_status' )
            ];

            if ( fusion_safe() && !empty( $_FILES['tgroup_pic'] ) && is_uploaded_file( $_FILES['tgroup_pic']['tmp_name'] ) ) {
                $upload = form_sanitizer( $_FILES['tgroup_pic'], '', 'tgroup_pic' );
                if ( empty( $upload['error'] ) ) {
                    $inputData['tgroup_pic'] = $upload['image_name'];
                }
            } else if ( check_post( 'del_image' ) && check_post( 'tgroup_id' ) && post( 'tgroup_id', FILTER_VALIDATE_INT ) ) {
                $result = dbquery( $this->sqlTeam->getTeamGroupQuery( ['condition' => "tgroup_id = :tgroupid"] ), [':tgroupid' => post( 'tgroup_id' )] );
                if ( dbrows( $result ) ) {
                    $data = dbarray( $result );
                    if ( !empty( $data['tgroup_pic'] ) && file_exists( TEAM_GROUP . $data['tgroup_pic'] ) ) {
                        @unlink( TEAM_GROUP . $data['tgroup_pic'] );
                    }
                }
                $inputData['tgroup_pic'] = '';
            }
            if ( fusion_safe() ) {
                dbquery_insert( DB_MYTEAM_GROUP, $inputData, empty( $inputData['tgroup_id'] ) ? 'save' : 'update' );
                addnotice( 'success', empty( $inputData['tgroup_id'] ) ? self::$locale['TEAM_E15'] : self::$locale['TEAM_E16'] );
                redirect( clean_request( '', ['action'], FALSE ) );
            }
        }

        $info = [
            'openform'  => openform( 'groupFrm', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] ),
            'tgroup_id'     => form_hidden( 'tgroup_id', '', self::$def_teamgroup['tgroup_id'] ),
            'tgroup_name'   => form_text( 'tgroup_name', self::$locale['TEAM_055'], self::$def_teamgroup['tgroup_name'], [
                'inline'     => TRUE,
                'required'   => TRUE
            ] ),
            'tgroup_pic'         => !empty( self::$def_teamgroup['tgroup_pic'] ) ?
                "<div id='team_user_id-field' class='form-group row'>
                    <label class='control-label col-xs-12 col-sm-12 col-md-3 col-lg-3'>" . self::$locale['TEAM_056'] . "</label>
                    <div class='col-xs-12 col-sm-12 col-md-9 col-lg-9'>
                        <div class='text-left m-r-10'>
                            " . thumbnail( TEAM_GROUP . self::$def_teamgroup['tgroup_pic'], '200px' ) . "
                        </div>
                        <div class='overflow-hide'>
                            " . form_checkbox( 'del_image', self::$locale['delete'], '' ) .
                            form_hidden( 'tgroup_pic', '', self::$def_teamgroup['tgroup_pic'] ) . "
                        </div>
                    </div>
                </div>" : form_fileinput( 'tgroup_pic', self::$locale['TEAM_056'], '', [
                    'upload_path'     => TEAM_GROUP,
                    'inline'          => TRUE,
                    'multiple'        => FALSE,
                    'delete_original' => FALSE,
                    'template'        => 'modern',
                    'class'           => 'm-b-0',
                    'max_width'       => $this->teamSettings['team_photo_w'],
                    'max_height'      => $this->teamSettings['team_photo_h'],
                    'max_byte'        => $this->teamSettings['team_photo_b'],
                    'ext_tip'         => sprintf( self::$locale['TEAM_032'], parsebytesize( $this->teamSettings['team_photo_b'] ), str_replace( ',', ' ', ".jpg,.gif,.png" ), $this->teamSettings['team_photo_w'], $this->teamSettings['team_photo_h'] )
            ] ),
            'tgroup_parent' => form_select_tree('tgroup_parent', self::$locale['TEAM_057'], self::$def_teamgroup['tgroup_parent'], [
                'inline'        => TRUE,
                'disable_opts'  => self::$def_teamgroup['tgroup_id'],
                'hide_disabled' => TRUE,
            ], DB_MYTEAM_GROUP, "tgroup_name", "tgroup_id", "tgroup_parent" ),
            'tgroup_status' => form_select('tgroup_status', self::$locale['TEAM_036'], self::$def_teamgroup['tgroup_status'], [
                'inline'      => TRUE,
                'options'     => [self::$locale['TEAM_039'], self::$locale['TEAM_037']],
                'placeholder' => self::$locale['choose'],
            ] ),
            'butonsave' => form_button('save_group', self::$locale['save'], self::$locale['save'], ['class' => 'btn-sm btn-primary', 'icon' => 'fa fa-floppy-o']),
            'closeform'        => closeform()
        ];
        groupForm( $info );
    }

    private function groupList() {
        $data = dbquery_tree_full( DB_MYTEAM_GROUP, "tgroup_id", "tgroup_parent", "",
            "SELECT ac.*, COUNT(a.team_id) AS teamcount
            FROM " . DB_MYTEAM_GROUP . " ac
            LEFT JOIN " . DB_MYTEAM . " AS a ON a.team_groups = ac.tgroup_id
            GROUP BY ac.tgroup_id
            ORDER BY ac.tgroup_parent ASC, ac.tgroup_id ASC"
        );
        opentable( self::$locale['TEAM_M0'] );
        echo "<div class='clearfix text-left m-b-5'><a class='btn btn-success btn-sm' href='" . clean_request( "action=newgroup", ["action"], FALSE ) . "'><i class='fa fa-fw fa-plus m-r-10'></i>" . self::$locale['TEAM_058'] . "</a></div>";
        self::teamCatInfo( $data );
        echo "<div class='panel-footer m-t-5 text-center'>" . self::getFooter() . "</div>";
        closetable();
    }

    private static function teamCatInfo($data, $id = 0, $level = 0) {
        if ( !empty( $data[$id] ) ) {
            if ( !$id ) {
                echo "<div class='table-responsive'><table class='table table-hover'>
                    <thead>
                        <tr>
                            <th></th>
                            <th>" . self::$locale['TEAM_033'] . "</th>
                            <th>" . self::$locale['TEAM_036'] . "</th>
                            <th>" . self::$locale['TEAM_061'] . "</th>
                            <th>" . self::$locale['TEAM_041'] . "</th>
                        </tr>
                    </thead>
                    <tbody>";
            }

            foreach ( $data[$id] as $cat_id => $cdata ) {
            	$alink = empty( $cdata['tgroup_status'] ) ? 'publishgroup' : 'unpublishgroup';
                $activetitle = empty( $cdata['tgroup_status'] ) ? self::$locale['TEAM_059'] : self::$locale['TEAM_060'];
                $groupedit = clean_request( "section=group&action=editgroup&tgroup_id=" . $cat_id, ['section', 'action', 'tgroup_id'], FALSE);
                $groupdelete = clean_request( "section=group&action=deletegroup&tgroup_id=" . $cat_id, ['section', 'action', 'tgroup_id'], FALSE);
                $groupactive = clean_request( "section=group&action=" . $alink . "&tgroup_id=" . $cat_id, ['section', 'action', 'tgroup_id'], FALSE);

            	echo "<tr data-id=" . $cat_id . " id=cat" . $cat_id . ">
            	    <td>". self::teamPic( TEAM_GROUP . $cdata['tgroup_pic'], '50' ) . "</td>
            	    <td>" . str_repeat( "-", $level ) . " " . $cdata['tgroup_name'] . "</td>
            	    <td>" . self::getTeamIcons( 'circle', 'm-l-10', ( !empty( $cdata['tgroup_status'] ) ? self::$locale['TEAM_037'] : self::$locale['TEAM_039'] ), "color:#" . ( !empty( $cdata['tgroup_status'] ) ? "5CB85C" : "FF4040" ) . ";" ) . "</td>
            	    <td><span class='badge'>" . format_word( $cdata['teamcount'], self::$locale['fmt_teams'] ) . "</span></td>
            	    <td><a href='" . $groupedit . "'>" . self::getTeamIcons( 'pencil', 'm-r-10', self::$locale['edit'] ) . "</a>
            	        || <a href='" . $groupdelete . "'>" . self::getTeamIcons( 'trash', 'm-l-10 m-r-10', self::$locale['delete'] ) . "</a>
            	        || <a href='" . $groupactive . "'>" . self::getTeamIcons( ( empty( $cdata['tgroup_status'] ) ? 'usercheck' : 'userslash' ), 'm-l-10', $activetitle ) . "
            	    <td>
            	</tr>\n";
                if ( isset( $data[$cdata['tgroup_id']] ) ) {
                    self::teamCatInfo( $data, $cdata['tgroup_id'], $level + 1 );
                }
            }
            if ( !$id ) {
                echo "</tbody>
                </table></div>";
            }
        } else {
            echo "<div class='text-center well'>" . self::$locale['TEAM_E17'] . "</div>";
        }
    }

    private function groupMod( $mod = NULL, $id = NULL ) {
        dbquery( "UPDATE " . DB_MYTEAM_GROUP . " SET tgroup_status = :status WHERE tgroup_id = :tgroupid", [':status' => $mod, ':tgroupid' => (int)$id] );
    }

    private function delGroup( $catid ) {
        if ( !dbcount("(team_id)", DB_MYTEAM, "team_groups = :teamgroups", [':teamgroups' => (int)$catid] ) && !dbcount( "(tgroup_id)", DB_MYTEAM_GROUP, "tgroup_parent = :tgparent", [':tgparent' => (int)$catid] ) ) {
            $result = dbquery( $this->sqlTeam->getTeamGroupQuery( ['condition' =>"tgroup_id = :tgroupid"] ), [':tgroupid' => $catid] );
            dbquery( "DELETE FROM " . DB_MYTEAM_GROUP . " WHERE tgroup_id = :tgid", [':tgid' => (int)$catid] );
            if ( dbrows( $result ) ) {
                $data = dbarray( $result );
                if ( !empty( $data['tgroup_pic'] ) && file_exists( TEAM_GROUP . $data['tgroup_pic'] ) ) {
                    @unlink( TEAM_GROUP . $data['tgroup_pic'] );
                }
            }
            addnotice( 'success', self::$locale['TEAM_E18'] );
        } else {
            addnotice( 'warning', self::$locale['TEAM_E19'] );
        }
    }
}
