<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/admin_settings.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class AdminSettings extends TeamServer {
    private static $instance = NULL;

    public function __construct() {
        parent::__construct();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }
        return self::$instance;
    }

    public function startSettings() {
        if ( check_post( 'savesettings' ) ) {
			$inputArray = [
				'team_submit'        => post( 'team_submit' ) ? 1 : 0,
				'team_submit_access' => sanitizer( ['team_submit_access'], 0, 'team_submit_access' ),
				'team_photo_w'       => sanitizer( 'team_photo_w', '1024', 'team_photo_w' ),
				'team_photo_h'       => sanitizer( 'team_photo_h', '768', 'team_photo_h' ),
				'team_photo_b'       => sanitizer( 'calc_b', '15', 'calc_b' ) * sanitizer( 'calc_c', '100000', 'calc_c' ),
				'team_pagination'    => sanitizer( 'team_pagination', 0, 'team_pagination' ),
				'team_nametype'      => sanitizer( ['team_nametype'], 0, 'team_nametype' ),
				'team_groupuse'      => sanitizer( 'team_groupuse', 0, 'team_groupuse' ),
				'team_email'         => sanitizer( 'team_email', 0, 'team_email' ),
				'team_file_types'    => sanitizer( ['team_file_types'], '.gif,.jpg,.png,.svg,.webp', 'team_file_types' )
			];

            if ( fusion_safe() ) {
                foreach ( $inputArray as $settings_name => $settings_value ) {
                    $inputSettings = [
                        'settings_name'  => $settings_name,
                        'settings_value' => $settings_value,
                        'settings_inf'   => TEAM_FOLDER
                    ];
                    dbquery_insert( DB_SETTINGS_INF, $inputSettings, 'update', ['primary_key' => 'settings_name'] );
                }
                addnotice( 'success', self::$locale['TEAM_015'] );
                redirect( clean_request( '', ['section', 'aid'], TRUE ) );
            }
        }
        $tab_cats = [
            'title' => [self::$locale['TEAM_M3'], self::$locale['TEAM_M4'], self::$locale['TEAM_M5']],
            'id'    => ['prsettings', "addprofil", "delprofil"],
            'icon'  => ['', '', '']
        ];
        $tab_cats_active = tab_active( $tab_cats, 0 );
        opentable( self::$locale['TEAM_M3'] );
        echo opentab( $tab_cats, $tab_cats_active, 'dcategory', FALSE, "nav-tabs" );
        echo opentabbody( $tab_cats['title'][0], $tab_cats['id'][0], $tab_cats_active );
        openside( ' ' );
        echo openform( 'settingsform', 'POST' );
        echo self::settingsForm();
        closeside();
        echo form_button('savesettings', self::$locale['save'], self::$locale['save'], ['class' => 'btn-success', 'icon' => 'fa fa-hdd-o']);
        closeform();
        echo closetabbody();
        echo opentabbody( $tab_cats['title'][1], $tab_cats['id'][1], $tab_cats_active );
        openside( ' ' );
            self::profilAdd();
        closeside();
        echo closetabbody();
        echo opentabbody( $tab_cats['title'][2], $tab_cats['id'][2], $tab_cats_active );
        openside( ' ' );
            self::profilRemov();
        closeside();
        echo closetabbody();
        echo closetab();

        closetable();
    }

    private static function profilAdd() {
        $info = self::profilList('add');
        if ( !empty( $info ) ) {
            if ( check_post( 'add_group' ) ) {
                $svadat = sanitizer( ['addform'], '', 'addform');
                $svadat1 = explode( ',', $svadat );
                $i = 0;
                foreach ( $svadat1 as $id => $value ) {
                    if ( !empty( self::$loadField[$value]['type'] ) ) {
                        dbquery( "ALTER TABLE " . DB_MYTEAM_FIELD . " ADD {$value} " . self::$loadField[$value]['type'] . " AFTER field_teamid" );
                        $i++;
                    }
                }
                addnotice( 'success', $i . self::$locale['TEAM_016'] );
                redirect( clean_request( '', ['action'], FALSE ) );
            }
            echo openform( 'groupFrm', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] );
            foreach ( $info as $id => $value ) {
                echo form_checkbox( 'addform[]', $value, 0, [
                    'inline'        => TRUE,
                    'type'          => 'checkbox',
                    'value'         => $id,
                    'input_id'      => 'reset-id-'.$id,
                    'reverse_label' => TRUE
                ] );
            }
            echo form_button( 'add_group', self::$locale['save'], self::$locale['save'], ['class' => 'btn-sm btn-primary', 'icon' => 'fa fa-floppy-o'] );
            echo closeform();
        } else {
            echo "<div class='text-center well'>" . self::$locale['TEAM_E00'] . "</div>";
        }
    }

    private function profilRemov() {
        $info = self::profilList('remov');
        if ( !empty( $info ) ) {
            if ( check_post( 'save_group' ) ) {
                $svadat = sanitizer( ['removform'], '', 'removform');
                $svadat1 = explode( ',', $svadat );
                $i = 0;
                foreach ( $svadat1 as $id => $value ) {
                    dbquery( "ALTER TABLE " . DB_MYTEAM_FIELD . " DROP {$value}" );
                    $i++;
                }
                addnotice( 'success', $i . self::$locale['TEAM_017'] );
                redirect( clean_request( '', ['action'], FALSE ) );
            }
            echo openform( 'groupFrm', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] );
            foreach ( $info as $id => $value ) {
                echo form_checkbox( 'removform[]', $value, 0, [
                    'inline'        => TRUE,
                    'type'          => 'checkbox',
                    'value'         => $id,
                    'input_id'      => 'reset-id-'.$id,
                    'reverse_label' => TRUE
                ] );
            }
            echo form_button( 'save_group', self::$locale['delete'], self::$locale['delete'], ['class' => 'btn-sm btn-danger', 'icon' => 'fa fa-trash'] );
            echo closeform();
            add_to_jquery( "$('#save_group').bind('click', function() { return confirm('" . self::$locale['TEAM_E01'] . "'); });" );
        } else {
            echo "<div class='text-center well'>" . self::$locale['TEAM_E02'] . "</div>";
        }
    }

    private function settingsForm() {
        $mime = mimetypes();
        $mime_opts = [];
        foreach ( $mime as $m => $Mime ) {
            $ext = ".$m";
            $mime_opts[$ext] = $ext;
        }
        $html = form_text( 'team_photo_w', self::$locale['TEAM_018'], $this->teamSettings['team_photo_w'], [
            'required'       => TRUE,
            'inline'         => TRUE,
            'max_length'     => 4,
            'type'           => 'number',
            'prepend'        => TRUE,
            'floating_label' => TRUE
        ] );
        $html .= form_text( 'team_photo_h', self::$locale['TEAM_019'], $this->teamSettings['team_photo_h'], [
            'required'       => TRUE,
            'inline'         => TRUE,
            'max_length'     => 4,
            'type'           => 'number',
            'prepend'        => TRUE,
            'floating_label' => TRUE
        ] );
        $calc_c = calculate_byte( $this->teamSettings['team_photo_b'] );
        $calc_b = $this->teamSettings['team_photo_b'] / $calc_c;
        $html .= form_text( 'calc_b', self::$locale['TEAM_020'], $calc_b, [
            'required'    => TRUE,
            'inline'      => TRUE,
            'type'        => 'number',
            'error_text'  => self::$locale['error_rate'],
            'width'       => '100%',
            'max_length'  => 4,
            'append'      => TRUE,
            'append_html' => form_select( 'calc_c', '', $calc_c, [
                'options'     => [
                    1       => self::$locale['global_461'],
                    1024    => 'Kb',
                    1048576 => 'Mb'
                ], // $locale['admins_1020'],
                'placeholder' => self::$locale['choose'],
                'class'       => 'm-0',
                'width'       => '100',
                'inner_width' => '100px'
            ] )
        ] );
        $html .= form_select( 'team_file_types[]', self::$locale['TEAM_021'], $this->teamSettings['team_file_types'], [
            'required' => TRUE,
            'options'  => $mime_opts,
            'inline'   => TRUE,
            'multiple' => TRUE
        ] );
        $html .= form_text( 'team_pagination', self::$locale['TEAM_022'], $this->teamSettings['team_pagination'], [
            'required'    => TRUE,
            'inline'      => TRUE,
            'number'      => TRUE,
            'max_length'  => 4,
            'type'        => 'number',
            'inner_width' => '150px'
        ] );
        $html .= form_select( 'team_submit_access[]', self::$locale['submit_access'], $this->teamSettings['team_submit_access'], [
            'inline'   => TRUE,
            'options'  => fusion_get_groups( [USER_LEVEL_PUBLIC] ),
            'multiple' => TRUE
        ] );
        $html .= form_select( 'team_nametype[]', self::$locale['TEAM_024'], $this->teamSettings['team_nametype'], [
            'required'   => TRUE,
            'options'    => [0 => self::$locale['TEAM_025'], 1 => self::$locale['TEAM_026'], 2 => self::$locale['TEAM_027']],
            'inline'     => TRUE,
            'multiple'   => TRUE,
            'max_select' => TRUE
        ] );
        $html .= "<hr>";
        $html .= form_checkbox( 'team_submit', self::$locale['TEAM_023'], $this->teamSettings['team_submit'], [
            'inline' => TRUE,
            'toggle' => TRUE
        ] );
        $html .= form_checkbox( 'team_groupuse', self::$locale['TEAM_028'], $this->teamSettings['team_groupuse'], [
            'inline' => TRUE,
            'toggle' => TRUE
        ] );
        $html .= form_checkbox( 'team_email', self::$locale['TEAM_029'], $this->teamSettings['team_email'], [
            'inline'  => TRUE,
            'toggle'  => TRUE,
            'ext_tip' => self::$locale['TEAM_E23']
        ] );
        return $html;
    }

    private static function profilList( $id = '') {
        //databaselist
        $iData = [];
        $datalist = self::teamFieldList( 1 );
        foreach ( self::$teamMakefile as $fieldname ) {
            $file = str_replace( ['.php'], '', $fieldname );
            if ( !in_array( self::$fieldfile[$file], $datalist ) ) {
                $iData['add'][self::$fieldfile[$file]] = self::$loadField[$file]['locale'];
            } else {
                $iData['remov'][self::$fieldfile[$file]] = self::$loadField[$file]['locale'];
            }
            self::$field = self::$loadField;
        }
    	return $id ? ( !empty( $iData[$id] ) ? $iData[$id] : [] ) : $iData;
    }
}
