<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/admin_submit.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class AdminSubmit extends TeamServer {
    private static $instance = NULL;
    private $inputArray;

    public function __construct() {
        parent::__construct();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }
        return self::$instance;
    }

    public function startAdmin() {
        if ( check_post( 'publish_submission' ) ) {
            self::handlePostSubmission();
        }
        if ( check_post( 'delete_submission' ) && get( 'submit_id', FILTER_VALIDATE_INT ) ) {
            $result = dbquery( $this->sqlTeam->getSubmissionQuery( ['condition' => "submit_type = :type AND submit_id = :submitid"] ), [':type' => 't', ':submitid' => get( 'submit_id' )] );
            if ( dbrows( $result ) ) {
                $callback_data = dbarray( $result );
                $delCriteria = \Defender::decode( $callback_data['submit_criteria'] );
                if ( !empty( $delCriteria['team_pic'] ) && file_exists( TEAM_PATH . 'submissions/' . $delCriteria['team_pic'] ) ) {
                    unlink( TEAM_PATH . 'submissions/' . $delCriteria['team_pic'] );
                }
                self::handleDeleteSubmission( get( 'submit_id' ) );
                addnotice( "success", self::$locale['TEAM_E24'] );
            }
        }
        if ( check_get( 'submit_id' ) && get( 'submit_id' ) && dbcount( "(submit_id)", DB_SUBMISSIONS, "submit_id = :submitid AND submit_type = :submittype", [':submitid' => get( 'submit_id'), ':submittype' => 't'] ) ) {
            $this->inputArray = self::unserializeData();
            self::displayForm();
        } else {
            self::displaySubmissionList();
        }
    }

    private function unserializeData() {
        $result = dbquery( $this->sqlTeam->getSubmissionQuery( ['condition' => "submit_id = :submitid"] ), [':submitid' => get( 'submit_id' )] );
        if ( dbrows( $result ) ) {
            $data = dbarray( $result );
            $submit_criteria = \Defender::decode( $data['submit_criteria'] );
            $info = [
                'team_user_id'   => $data['submit_user'],
                'team_datestamp' => $data['submit_datestamp'],
                'team_status'    => 0,
            ] + $submit_criteria;
            return $info;
        } else {
            redirect( clean_request( '', [], FALSE ) );
        }
    }

    public function displayForm() {
        $datauser = fusion_get_user( $this->inputArray['team_user_id'] );
        $submissionUser = ( $datauser['user_name'] != self::$locale['user_na'] ? profile_link( $datauser['user_id'], $datauser['user_name'], $datauser['user_status'] ) : self::$locale['user_na'] );
        $submissionDate = showdate( "shortdate", $this->inputArray['team_datestamp'] );
        $submissionTime = timer( $this->inputArray['team_datestamp'] );
        $replacements = ["{%SUBMISSION_AUTHOR%}" => $submissionUser, "{%SUBMISSION_DATE%}" => $submissionDate, "{%SUBMISSION_TIME%}" => $submissionTime];
        $submissionInfo = strtr( self::$locale['TEAM_045'] . "<br />" . self::$locale['TEAM_046'], $replacements );
        foreach ( self::teamFieldList( 1 ) as $id => $field_data ) {
            if ( in_array( $field_data, self::$fieldfile ) ) {
                $field_list[$id] = sprintf( self::$loadField[$id]['form'], $this->inputArray[$id] );
            }
        }

        $info = [
            'tablename' => self::$locale['TEAM_047'],
            'avatar'         => display_avatar( $datauser, '30px', '', FALSE, 'img-rounded m-r-5' ),
            'submissionInfo' => $submissionInfo,
            'table'     => [
                'openform'         => openform( 'submitform', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] ),
                'team_id'          => form_hidden( 'team_id', '', '' ),
                'field_id'         => form_hidden( 'field_id', '', '' ),
                'team_datestamp'   => form_hidden( 'team_datestamp', '', $this->inputArray['team_datestamp'] ),
                'team_user_id'     => form_hidden( 'team_user_id', '', $this->inputArray['team_user_id'] ),
                'team_real_name'   => form_text( 'team_real_name', self::$locale['TEAM_026'], $this->inputArray['team_real_name'], [
                    'inline'     => TRUE,
                    'required'   => $this->teamSettings['team_nametype'] == 1 ? TRUE : FALSE,
                    'placeholder' => self::$locale['TEAM_026']
                ] ),
                'team_nickname'    => form_text( 'team_nickname', self::$locale['TEAM_027'], $this->inputArray['team_nickname'], [
                    'inline'     => TRUE,
                    'required'   => $this->teamSettings['team_nametype'] == 2 ? TRUE : FALSE,
                ] ),
                'team_pic'         => !empty( $this->inputArray['team_pic'] ) ?
                    "<div id='team_user_id-field' class='form-group row'>
                        <label class='control-label col-xs-12 col-sm-12 col-md-3 col-lg-3'>" . self::$locale['TEAM_031'] . "</label>
                        <div class='col-xs-12 col-sm-12 col-md-9 col-lg-9'>
                            <div class='text-left m-r-10'>
                                " . thumbnail( TEAM_PATH . 'submissions/' . $this->inputArray['team_pic'], '80px' ) . "
                            </div>
                            <div class='overflow-hide'>
                                " . form_hidden( 'team_pic', '', $this->inputArray['team_pic'] ) . "
                            </div>
                        </div>
                    </div>" : form_fileinput( 'team_pic', self::$locale['TEAM_031'], '', [
                        'upload_path'     => TEAM_PATH . 'submissions/',
                        'inline'          => TRUE,
                        'multiple'        => FALSE,
                        'delete_original' => FALSE,
                        'template'        => 'modern',
                        'class'           => 'm-b-0',
                        'max_width'       => $this->teamSettings['team_photo_w'],
                        'max_height'      => $this->teamSettings['team_photo_h'],
                        'max_byte'        => $this->teamSettings['team_photo_b'],
                        'ext_tip'         => sprintf( self::$locale['TEAM_032'], parsebytesize( $this->teamSettings['team_photo_b'] ), str_replace( ',', ' ', ".jpg,.gif,.png" ), $this->teamSettings['team_photo_w'], $this->teamSettings['team_photo_h'] )
                ] ),
                'team_groups'      => form_select_tree( 'team_groups', self::$locale['TEAM_033'], $this->inputArray['team_groups'], [
                    'inline'       => TRUE,
                    'parent_value' => self::$locale['choose'],
                ], DB_MYTEAM_GROUP, "tgroup_name", "tgroup_id", "tgroup_parent" ),
                'team_position'    => form_text( 'team_position', self::$locale['TEAM_034'], $this->inputArray['team_position'], [
                    'inline'   => TRUE,
                    'required' => TRUE,
                ] ),
                'team_description' => form_textarea( 'team_description', self::$locale['TEAM_035'], $this->inputArray['team_description'], [
                    'inline'    => TRUE,
                    'html'      => TRUE,
                    'form_name' => 'submitform'
                ] ),
                'team_status'      => form_select( 'team_status', self::$locale['TEAM_036'], $this->inputArray['team_status'], [
                    'inline'      => TRUE,
                    'options'     => [1 => self::$locale['TEAM_037'], 0 => self::$locale['TEAM_038'], 2 => self::$locale['TEAM_039']],
                    'placeholder' => self::$locale['choose'],
                ] )
            ] + $field_list
             + [
                'team_language'    => multilang_table( "TEAM" ) ? form_select( 'team_language[]', self::$locale['language'], $this->inputArray['team_language'], [
                    'inline'      => TRUE,
                    'options'     => fusion_get_enabled_languages(),
                    'placeholder' => self::$locale['choose'],
                    'inner_width' => '100%',
                    'multiple'    => TRUE
                ] ) : form_hidden( 'team_language', '', LANGUAGE ),
                'buton'            => form_button( 'publish_submission', self::$locale['TEAM_048'], self::$locale['TEAM_048'], ['class' => 'btn-success'] ).
            form_button( 'delete_submission', self::$locale['delete'], self::$locale['delete'], ['class' => 'btn-danger'] ),
                'closeform' => closeform()
            ]
        ];
        teamSubmitList($info);
    }

    private function displaySubmissionList() {
        $result = dbquery( $this->sqlTeam->getSubmitQuery() );
        if ( dbrows( $result ) ) {
            echo "<div class='table-responsive'>
                <table class='table table-striped'>
                    <thead>
                        <tr>
                            <th>" . self::$locale['TEAM_049'] . "</th>
                            <th>" . self::$locale['TEAM_050'] . "</th>
                            <th>" . self::$locale['TEAM_051'] . "</th>
                            <th>" . self::$locale['TEAM_041'] . "</th>
                        </tr>
                    </thead>
                    <tbody>";
                    while ( $callback_data = dbarray( $result ) ) {
                        echo "<tr>
                            <td>" . $callback_data['submit_id'] . "</td>
                            <td>" . display_avatar( $callback_data, '20px', '', TRUE, 'img-rounded m-r-5' ), profile_link( $callback_data['user_id'], $callback_data['user_name'], $callback_data['user_status'] ) . "</td>
                            <td>" . timer( $callback_data['submit_datestamp'] ) . "</td>
                            <td><a href='" . clean_request( 'submit_id=' . $callback_data['submit_id'], ['section', 'aid'] ) . "'>" . self::$locale['TEAM_052'] . "</a></td>
                        </tr>";
                    }
                    echo "</tbody>
                </table>
            </div>";
        } else {
            echo "<div class='well text-center'>" . self::$locale['TEAM_E12'] . "</div>";
        }
    }

    private function handleDeleteSubmission( $submitid = '' ) {
        dbquery( "DELETE FROM " . DB_SUBMISSIONS . " WHERE submit_id = :submitid AND submit_type = :submittype", [':submitid' => (int)$submitid, ':submittype' => 't'] );
    }

    private function handlePostSubmission() {
        $settings = fusion_get_settings();
        $iData['field_id'] = sanitizer( 'field_id', '', 'field_id' );
        $iData['field_teamid'] = sanitizer( 'team_id', '', 'team_id' );
        $fields = explode( ',', self::teamFieldList() );
        foreach ( $fields as $tid => $tdata ) {
            $iData[$tdata] = sanitizer( $tdata, '', $tdata );
        }
        $inputData = [
            'team_id'          => sanitizer( 'team_id', '', 'team_id' ),
            'team_user_id'     => sanitizer( 'team_user_id', 0, 'team_user_id' ),
            'team_real_name'   => sanitizer( 'team_real_name', '', 'team_real_name' ),
            'team_nickname'    => sanitizer( 'team_nickname', '', 'team_nickname' ),
            'team_groups'      => sanitizer( 'team_groups', '', 'team_groups' ),
            'team_position'    => sanitizer( 'team_position', '', 'team_position' ),
            'team_pic'         => sanitizer( 'team_pic', '', 'team_pic' ),
            'team_description' => sanitizer( 'team_description', '', 'team_description' ),
            'team_count'       => 0,
            'team_status'      => sanitizer( 'team_status', 0, 'team_status' ),
            'team_active'      => sanitizer( 'team_active', 0, 'team_active' ),
            'team_inactivdesc' => '',
            'team_datestamp'   => sanitizer( 'team_datestamp', 0, 'team_datestamp' ),
            'team_enddate'     => 0,
            'team_language'    => sanitizer( 'team_language', LANGUAGE, 'team_language' )
        ];
        // move images
        if ( fusion_safe() ) {
            if ( !empty( $inputData['team_pic'] ) && file_exists( TEAM_PATH . 'submissions/' . $inputData['team_pic'] ) ) {
                $dest = TEAM_TEAM;
                $temp_file = $inputData['team_pic'];
                $inputData['team_pic'] = filename_exists($dest, $inputData['team_pic']);
                copy( TEAM_PATH . 'submissions/' . $temp_file, $dest . $inputData['team_pic'] );
                chmod( $dest . $inputData['team_pic'], 0644 );
                unlink( TEAM_PATH . 'submissions/' . $temp_file );
            }
            $dataid = dbquery_insert( DB_MYTEAM, $inputData, 'save' );
            $iData['field_teamid'] = $dataid;
            dbquery_insert( DB_MYTEAM_FIELD, $iData, 'save' );
            self::handleDeleteSubmission( get( 'submit_id' ) );
            if ( !empty( $this->teamSettings['team_email'] ) ) {
                require_once INCLUDES."sendmail_include.php";
                $message = str_replace(
                    ["[USER_NAME]", '[SITENAME]', '[SITEUSERNAME]'],
                    [$inputData['team_real_name'], $settings['sitename'], $settings['siteusername']],
                    self::$locale['TEAM_074']
                );
                sendemail( $inputData['team_real_name'], $inputData['user_email'], $settings['siteusername'], $settings['siteemail'],
                    str_replace('[SITENAME]', fusion_get_settings('sitename'), self::$locale['TEAM_073']), $message
                );
            }
            addnotice( 'success', self::$locale['TEAM_053'] );
            redirect( clean_request( '', ['submit_id'], FALSE ) );
        }
    }
}
