<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/cat_admin.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class AdminUser extends TeamServer {
    private static $instance = NULL;

    public function __construct() {
        parent::__construct();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }
        return self::$instance;
    }

    public function startUserAdmin() {
        switch ( $this->action ) {
            case "newuser":
                self::teamUserForm();
                break;
            case "edituser":
                self::teamUserForm( get( 'team_id', FILTER_VALIDATE_INT ) );
                break;
            case "deleteuser":
                if ( iADMIN && get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::delTeamUser( get( 'team_id', FILTER_VALIDATE_INT ) );
                    addnotice( 'success', self::$locale['TEAM_E03'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "publishuser":
                if ( get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 1, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_E04'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "unpublishuser":
                if ( get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 0, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_E05'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            default:
                self::userList();
                break;
        }
    }

    private function editTeamUser( $teamuser = NULL ) {
        if ( !empty( $teamuser ) && isnum( $teamuser ) ) {
            foreach ( self::teamFieldList(1) as $headid => $headdata ) {
                $head_info[] = 'tf.' . $headid;
            }
        $sql_head = implode( ', ', $head_info );
        $sql_condition = ( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ) . ' AND ' : '' ) . "team_id = :tgid";
        $result = dbquery( "SELECT a.*, ac.*, tf.field_id, tf.field_teamid, $sql_head, tu.user_id, tu.user_name, tu.user_status, tu.user_avatar
            FROM " . DB_MYTEAM . " AS a
            LEFT JOIN " . DB_MYTEAM_GROUP . " AS ac ON ac.tgroup_id = a.team_groups
            LEFT JOIN " . DB_MYTEAM_FIELD . " AS tf ON tf.field_teamid = a.team_id
            LEFT JOIN " . DB_USERS . " AS tu ON tu.user_id = a.team_user_id
            " . ( $sql_condition ? "WHERE " . $sql_condition : "" ) . "
        ", [':tgid' => $teamuser]);
            if ( dbrows( $result ) ) {
                self::$def_teamuser = dbarray( $result );
            } else {
                redirect( clean_request( '', ['action'], FALSE ) );
            }
        }
    }

    private function teamUserForm( $teamuser = NULL) {
        if ( !empty( $teamuser ) ) {
            self::editTeamUser( $teamuser );
        }

        $fieldlist = makefilelist( TEAM_PATH . 'team_field/', ".|..|index.php", TRUE );
        foreach ( $fieldlist as $image ) {
            $file = str_replace( ['.php'], '', $image );
            if ( empty( $teamuser ) ) {
                self::$def_teamuser[$file] = '';
            }
        }
        //adatbazis
        foreach ( self::teamFieldList( 1 ) as $id => $field_data ) {
            if ( in_array( $field_data, self::$fieldfile ) ) {
                $field_list[$id] = sprintf( self::$loadField[$id]['form'], self::$def_teamuser[$id] );
            }
        }

        if ( check_post( 'save_group' ) ) {
            $iData['field_id'] = sanitizer( 'field_id', '', 'field_id' );
            $iData['field_teamid'] = sanitizer( 'team_id', '', 'team_id' );
            $fields = explode( ',', self::teamFieldList() );
            foreach ( self::$def_teamuser as $tid => $tdata ) {
                if ( in_array( $tid, $fields ) ) {
                    $iData[$tid] = sanitizer( $tid, $tdata, $tid );
                }
            }
            $inputData = [
                'team_id'          => sanitizer( 'team_id', '', 'team_id' ),
                'team_user_id'     => sanitizer( 'team_user_id', 0, 'team_user_id' ),
                'team_real_name'   => sanitizer( 'team_real_name', '', 'team_real_name' ),
                'team_nickname'    => sanitizer( 'team_nickname', '', 'team_nickname' ),
                'team_groups'      => sanitizer( 'team_groups', '', 'team_groups' ),
                'team_position'    => sanitizer( 'team_position', '', 'team_position' ),
                'team_pic'         => sanitizer( 'team_pic', '', 'team_pic' ),
                'team_description' => sanitizer( 'team_description', '', 'team_description' ),
                'team_count'       => sanitizer( 'team_count', 0, 'team_count' ),
                'team_status'      => sanitizer( 'team_status', 0, 'team_status' ),
                'team_active'      => sanitizer( 'team_active', 0, 'team_active' ),
                'team_enddate'     => sanitizer( 'team_enddate', 0, 'team_enddate' ),
                'team_inactivdesc' => sanitizer( 'team_inactivdesc', '', 'team_inactivdesc' ),
                'team_language'    => sanitizer( 'team_language', LANGUAGE, 'team_language' )
            ];
            if ( fusion_safe() && !empty( $_FILES['team_pic'] ) && is_uploaded_file( $_FILES['team_pic']['tmp_name'] ) ) {
                $upload = form_sanitizer( $_FILES['team_pic'], '', 'team_pic' );
                if ( empty( $upload['error'] ) ) {
                    $inputData['team_pic'] = $upload['image_name'];
                }
            } else if ( check_post( 'del_image' ) && check_post( 'team_id' ) && post( 'team_id', FILTER_VALIDATE_INT ) ) {
                $result = dbquery("SELECT team_pic FROM " . DB_MYTEAM . " WHERE team_id = :teamid", [':teamid' => post( 'team_id' )] );
                if ( dbrows( $result ) ) {
                    $data = dbarray( $result );
                    if ( !empty( $data['team_pic'] ) && file_exists( TEAM_TEAM . $data['team_pic'] ) ) {
                        @unlink( TEAM_TEAM . $data['team_pic'] );
                    }
                }
                $inputData['team_pic'] = '';
            }
            if ( fusion_safe() ) {
                empty( $inputData['team_id'] ) ? $inputData['team_datestamp'] = time() : '';
                $inputData['team_enddate'] = empty( $inputData['team_enddate'] ) && $inputData['team_status'] != 1 ? time() : 0;
                $dataid = dbquery_insert( DB_MYTEAM, $inputData, empty( $inputData['team_id'] ) ? 'save' : 'update' );
                $iData['field_teamid'] = empty( $iData['field_teamid'] ) ? $dataid : $iData['field_teamid'];
                dbquery_insert( DB_MYTEAM_FIELD, $iData, empty( $iData['field_id'] ) ? 'save' : 'update' );
                addnotice( 'success', empty( $inputData['team_id'] ) ? self::$locale['TEAM_E06'] : self::$locale['TEAM_E07'] );
                redirect( clean_request( '', ['action', 'team_id'], FALSE ) );
            }
        }

        $info = [
            'openform'         => openform( 'groupFrm', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] ),
            'team_id'          => form_hidden( 'team_id', '', self::$def_teamuser['team_id'] ),
            'team_enddate'     => form_hidden( 'team_enddate', '', self::$def_teamuser['team_enddate'] ),
            'field_id'         => form_hidden( 'field_id', '', self::$def_teamuser['field_id'] ),
            'team_user_id'     => form_select( 'team_user_id', self::$locale['TEAM_030'], self::$def_teamuser['team_user_id'], [
                'inline'      => TRUE,
                'options'     => self::teamUser(),
                'placeholder' => self::$locale['choose'],
            ] ),
            'team_pic'         => !empty( self::$def_teamuser['team_pic'] ) ?
                "<div id='team_user_id-field' class='form-group row'>
                    <label class='control-label col-xs-12 col-sm-12 col-md-3 col-lg-3'>" . self::$locale['TEAM_031'] . "</label>
                    <div class='col-xs-12 col-sm-12 col-md-9 col-lg-9'>
                        <div class='text-left m-r-10'>
                            " . thumbnail( TEAM_TEAM . self::$def_teamuser['team_pic'], '80px' ) . "
                        </div>
                        <div class='overflow-hide'>
                            " . form_checkbox( 'del_image', self::$locale['delete'], '' ) .
                            form_hidden( 'team_pic', '', self::$def_teamuser['team_pic'] ) . "
                        </div>
                    </div>
                </div>" : form_fileinput( 'team_pic', self::$locale['TEAM_031'], '', [
                    'upload_path'     => TEAM_TEAM,
                    'inline'          => TRUE,
                    'multiple'        => FALSE,
                    'delete_original' => FALSE,
                    'template'        => 'modern',
                    'class'           => 'm-b-0',
                    'max_width'       => $this->teamSettings['team_photo_w'],
                    'max_height'      => $this->teamSettings['team_photo_h'],
                    'max_byte'        => $this->teamSettings['team_photo_b'],
                    'ext_tip'         => sprintf( self::$locale['TEAM_032'], parsebytesize( $this->teamSettings['team_photo_b'] ), str_replace( ',', ' ', ".jpg,.gif,.png" ), $this->teamSettings['team_photo_w'], $this->teamSettings['team_photo_h'] )
            ] ),
            'team_groups'      => $this->teamSettings['team_groupuse'] ? form_select_tree( 'team_groups', self::$locale['TEAM_033'], self::$def_teamuser['team_groups'], [
                'inline'       => TRUE,
                'parent_value' => self::$locale['choose'],
            ], DB_MYTEAM_GROUP, "tgroup_name", "tgroup_id", "tgroup_parent" )  : form_hidden( 'team_groups', '', self::$def_teamuser['team_groups'] ),

            'team_real_name'   => form_text( 'team_real_name', self::$locale['TEAM_026'], self::$def_teamuser['team_real_name'], [
                'inline'     => TRUE,
                'required'   => $this->teamSettings['team_nametype'] == 1 ? TRUE : FALSE
            ] ),
            'team_nickname'   => form_text( 'team_nickname', self::$locale['TEAM_027'], self::$def_teamuser['team_nickname'], [
                'inline'     => TRUE,
                'required'   => $this->teamSettings['team_nametype'] == 2 ? TRUE : FALSE
            ] ),
            'team_position'    => form_text( 'team_position', self::$locale['TEAM_034'], self::$def_teamuser['team_position'], [
                'inline'     => TRUE,
                'required'   => TRUE,
            ] ),
            'team_description' => form_textarea( 'team_description', self::$locale['TEAM_035'], self::$def_teamuser['team_description'], [
                'inline'    => TRUE,
                'html'      => TRUE,
                'form_name' => 'groupFrm'
            ] ),
            'team_status'      => form_select( 'team_status', self::$locale['TEAM_036'], self::$def_teamuser['team_status'], [
                'inline'      => TRUE,
                'options'     => [1 => self::$locale['TEAM_037'], 0 => self::$locale['TEAM_038'], 2 => self::$locale['TEAM_039']],
                'placeholder' => self::$locale['choose'],
            ] ) . "<div id='teamDiv'" . ( self::$def_teamuser['team_status'] == 1 ? " style='display:none;'" : '' ) . ">" .  form_textarea( 'team_inactivdesc', self::$locale['TEAM_040'], self::$def_teamuser['team_inactivdesc'], [
                'inline'    => TRUE,
                'html'      => TRUE,
                'form_name' => 'groupFrm'
            ] ) . "</div>",
        ] + $field_list;
        $info += [
            'team_language'    => multilang_table( "TEAM" ) ? form_select( 'team_language[]', self::$locale['language'], self::$def_teamuser['team_language'], [
                'inline'      => TRUE,
                'options'     => fusion_get_enabled_languages(),
                'placeholder' => self::$locale['choose'],
                'inner_width' => '100%',
                'multiple'    => TRUE
            ] ) : form_hidden( 'team_language', '', self::$def_teamuser['team_language'] ),
            'butonsave' => form_button( 'save_group', self::$locale['save'], self::$locale['save'], ['class' => 'btn-sm btn-primary', 'icon' => 'fa fa-floppy-o'] ),
            'closeform' => closeform()
        ];
        groupForm( $info );
        add_to_jquery( "
            function statusmod(val) {
                if (val == '0' || val == '2') {
                    $('#teamDiv').slideDown('slow');
                } else {
                    $('#teamDiv').hide();
                }
            }
            $('#team_status').bind('change', function() {
                statusmod($(this).select2().val());
            });
        " );
    }

    private function userList() {
        $inf['tablename'] = self::$locale['TEAM_M1'];
        $inf['newlink'] = clean_request( "action=newuser", ["action"], FALSE );
        $inf['group'] = $this->teamSettings['team_groupuse'] ? dbcount( "(team_id)", DB_MYTEAM, "team_groups = 0" ) : 0;
        $inf['groupuse'] = $this->teamSettings['team_groupuse'];
        $inf['real_name_title'] = self::getNameTitle( $this->teamSettings['team_nametype'] );

        $sql_condition = ( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ) : '' );

        $result = dbquery( "SELECT a.*, ac.*, u.user_id, u.user_name, u.user_status, u.user_avatar
            FROM " . DB_MYTEAM . " AS a
            LEFT JOIN " . DB_MYTEAM_GROUP . " ac ON ac.tgroup_id = a.team_groups
            LEFT JOIN " . DB_USERS . " u ON u.user_id = a.team_user_id
            " . ( $sql_condition ? "WHERE " . $sql_condition : '' ) . "
            GROUP BY a.team_id
            ORDER BY team_real_name ASC
        " );
        if ( dbrows( $result ) ) {
            while ( $tl_users = dbarray( $result ) ) {
                $useredit = clean_request( "section=users&action=edituser&team_id=" . $tl_users['team_id'], ['section', 'action', 'team_id', 'rowstart'], FALSE );
                $userdelete = clean_request( "section=users&action=deleteuser&team_id=" . $tl_users['team_id'], ['section', 'action', 'team_id', 'rowstart'], FALSE );

                $tusers['avatar'] = self::teamPic( TEAM_TEAM . $tl_users['team_pic'],'50' );
                $tusers['real_name'] = $tl_users[$this->nametype[$this->teamSettings['team_nametype']]];
                $tusers['name'] = !empty( $tl_users['team_user_id'] ) ? profile_link( $tl_users['user_id'], $tl_users['user_name'], $tl_users['user_status'] ) : self::$locale['TEAM_E08'];
                $tusers['group'] = empty( $tl_users['team_groups'] ) ? self::$locale['TEAM_E09'] : $tl_users['tgroup_name'];
                $tusers['position'] = $tl_users['team_position'];
                $tusers['useredit'] = "<a href='" . $useredit . "'>" . self::getTeamIcons( 'pencil', 'm-l-10 m-r-10', self::$locale['edit'] ) . "</a>";
                $tusers['userdelete'] = "<a href='" . $userdelete . "'>" . self::getTeamIcons( 'trash', 'm-l-10 m-r-10', self::$locale['delete'] ) . "</a>";

                if ( $tl_users['team_active'] == 1 ) {
                    $inf['deluser'][] = $tusers;
                } else if ( $tl_users['team_status'] == 1 ) {
                    $inf['active'][] = $tusers;
                } else {
                    $inf['inactiv'][] = $tusers;
                }
            }
        } else {
            $inf['nouser'] = self::$locale['TEAM_E10'];
        }
        adminUserInfo( $inf );
    }
}
