<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/server.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

abstract class TeamServer {
    protected static $locale = [];
    public $sqlTeam = NULL;
    public $action = '';
    public $teamSettings = NULL;
    public $nametype = ['user_name', 'team_real_name', 'team_nickname'];
    public $action_pages = ['newuser', 'edituser', 'deleteuser', 'publishuser', 'unpublishuser', 'viewuser', 'newgroup', 'editgroup', 'deletegroup', 'publishgroup', 'unpublishgroup'];
    public $allowed_pages = ['group', 'users', 'submissions', 'settings'];
    protected static $field = [];
    protected static $teamMakefile = [];
    protected static $loadField = [];
    protected static $fieldfile = [];
    protected static $def_teamgroup = [
        'tgroup_id'     => '',
        'tgroup_name'   => '',
        'tgroup_parent' => 0,
        'tgroup_pic'    => '',
        'tgroup_status' => 1
    ];

    protected static $def_teamuser = [
        'team_id'          => '',
        'team_user_id'     => '',
        'team_real_name'   => '',
        'team_nickname'    => '',
        'team_groups'      => '',
        'team_position'    => '',
        'team_pic'         => '',
        'team_description' => '',
        'team_count'       => 0,
        'team_status'      => 1,
        'team_active'      => 0,
        'team_inactivdesc' => '',
        'team_datestamp'   => '',
        'team_enddate'     => '',
        'team_language'    => LANGUAGE,
        'field_id'         => '',
        'field_teamid'     => 0,
        'field_email'      => ''
    ];
    protected static $def_teamfield = [
        'field_id'     => '',
        'field_teamid' => '',
        'field_email'  => ''
    ];

    private static $team_icons = [
        'eye'       => 'fa fa-eye',
        'at'        => 'fa fa-at',
        'phone'     => 'fa fa-phone',
        'globe'     => 'fa fa-globe',
        'pencil'    => 'fa fa-pencil',
        'trash'     => 'fa fa-trash',
        'usercheck' => 'fa fa-user-check',
        'userslash' => 'fa fa-user-slash',
        'circle'    => 'fa fa-circle',
        'buton'     => 'fa fa-hdd-o'
    ];

    public function __construct() {
        include_once TEAM_PATH . 'templates/team.tpl.php';
        self::$locale = fusion_get_locale('', MYTEAM_LOCALE);
        $this->sqlTeam = new Teamsql();
        $this->teamSettings = get_settings( TEAM_FOLDER );
        $this->action = in_array( get( 'action' ), $this->action_pages ) ? get( 'action' ) : '';
        self::$teamMakefile = makefilelist( TEAM_PATH . 'team_field/', ".|..|index.php", TRUE );
        self::teamFieldFile();
        self::teamLoadField();
    }

	public static function getNameTitle( $id ) {
	    $titlearray = [self::$locale['TEAM_025'], self::$locale['TEAM_026'], self::$locale['TEAM_027']];
	    return !empty( $titlearray[$id] ) ? $titlearray[$id] : $titlearray;
	}

	public static function getGroup() {
	    return self::$def_teamgroup;
	}

	public static function getTeam() {
	    return self::$def_teamuser;
	}

    public static function getTeamIcons( string $name, string $class = "", string $tooltip = "", string $style = "" ) {
        $icon = (self::$team_icons[$name]) ?? $name;
        $style = $style ? " style='" . $style . "'" : '';
        $tooltip = $tooltip ? " data-toggle='tooltip' title='" . $tooltip . "'" : '';
        return "<i class='" . $icon . whitespace( $class ) . "'" . $style . $tooltip . "></i>";
    }

    public static function validGroup() {
        if ( dbcount( "(tgroup_id)", DB_MYTEAM_GROUP, "" ) ) {
            return TRUE;
        }
        return FALSE;
    }

    public static function teamUser() {
        $result = dbquery( "SELECT * FROM " . DB_USERS . " ORDER BY user_level DESC, user_name" );
        $teamuser = [0 => self::$locale['TEAM_042']];
        if ( dbrows( $result ) ) {
            while ( $member_list = dbarray( $result ) ) {
                $teamuser[$member_list['user_id']] = $member_list['user_name'];
            }
        }
        return $teamuser;
    }

    public function delTeamUser( $teamid ) {
        $result = dbquery( $this->sqlTeam->getTeamUserQuery( ['condition' =>"team_id = :teamid"] ), [':teamid' => $teamid] );
        dbquery( "DELETE FROM " . DB_MYTEAM . " WHERE team_id = :teamid", [':teamid' => (int)$teamid] );
        dbquery( "DELETE FROM " . DB_MYTEAM_FIELD . " WHERE field_teamid = :teamid", [':teamid' => (int)$teamid] );
        if ( dbrows( $result ) ) {
            $data = dbarray( $result );
            if ( !empty( $data['team_pic'] ) && file_exists( TEAM_TEAM . $data['team_pic'] ) ) {
                @unlink( TEAM_TEAM . $data['team_pic'] );
            }
        }
    }

    public function teamMod( $mod = NULL, $id = NULL ) {
        dbquery( "UPDATE " . DB_MYTEAM . " SET team_status = :status, team_enddate = :enddate, team_active = :active WHERE team_id = :teamid", [':status' => $mod, ':enddate' => ( $mod == 1 ? 0 : time() ), ':active' => ( $mod ? 0 : 'team_active' ),':teamid' => (int)$id] );
    }

    public function teamCount( $teamid = NULL ) {
        if ( dbcount( "(team_id)", DB_MYTEAM, "team_id = :teamid", [':teamid' => (int)$teamid] ) ) {
            dbquery( "UPDATE " . DB_MYTEAM . " SET team_count = team_count+1 WHERE team_id = '" . $teamid . "'" );
        }
    }

    public static function teamLoadField() {
        foreach ( self::$teamMakefile as $fieldname ) {
            include( TEAM_PATH . 'team_field/' . $fieldname );
            self::$loadField = $field;
        }
    }

    public static function teamFieldFile() {
        $fieldfile = [];
        foreach ( self::$teamMakefile as $field ) {
            $file = str_replace( ['.php'], '', $field );
            self::$fieldfile[$file] = $file;
        }
	    return self::$fieldfile;
    }

    public static function teamFieldList( $info = NULL) {
        $existing = [];
        $tablefield = array_flip( fieldgenerator( DB_MYTEAM_FIELD ) );
        foreach ($tablefield as $table_name => $table_cols) {
            $file = str_replace( ['field_id', 'field_teamid'], '', $table_name );
            if (!empty( $file ) ) {
                $existing[$table_name] = $table_name;
            }
        }
        return $info ? $existing : implode( ',', array_flip( $existing ) );
    }

    public static function teamPic( $pic = '', $height = '') {
    	$image = ( !empty( $pic ) && is_file( $pic ) ? $pic : IMAGES . 'imagenotfound.jpg' );
    	return "<img src='" . $image . "' height='" . $height . "' />";
    }

    public static function getFooter() {
        if (defined('ADMIN_PANEL')) {
	        return sprintf( self::$locale['TEAM_044'], self::getTeamIcons( 'circle', 'm-l-10 m-r-10', '', "color:#69b452;" ), self::getTeamIcons( 'circle', 'm-l-10', '', "color:#FF4040;" ) );
    	}
	    return sprintf( self::$locale['TEAM_043'], self::getTeamIcons( 'circle', '', '', "color:#69b452;" ), self::getTeamIcons( 'circle', '', '', "color:#FF4040;" ),
            self::getTeamIcons( 'circle', '', '', "color:#000000;" ) );
	}
}
