<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: classes/team.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class Teams extends TeamServer {
    private static $instance = NULL;
    private $teamdata;

    public function __construct() {
        parent::__construct();
        add_to_title( self::$locale['TEAM_003'] );
    }

    public static function getInstance() {
        if (self::$instance === NULL) {
            self::$instance = new static();
        }
       return self::$instance;
    }

    public function startTeam() {
        switch ( $this->action ) {
            case "viewuser":
                self::teamCount( get( 'team_id' ) );
                self::teamUserView( get( 'team_id' ) );
                break;
            case "edituser":
                self::teamUserEdit( get( 'team_id' ) );
                break;
            case "deleteuser":
                if ( get('team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamUserDel( get( 'team_id', FILTER_VALIDATE_INT ) );
                    addnotice( 'success', self::$locale['TEAM_E03'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "publishuser":
                if ( get( 'team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 1, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_E04'] );
                }
                redirect(clean_request('', ['action', 'team_id'], FALSE));
                break;
            case "unpublishuser":
                if ( get( 'team_id', FILTER_VALIDATE_INT ) ) {
                    self::teamMod( 0, get( 'team_id' ) );
                    addnotice( 'success', self::$locale['TEAM_E05'] );
                }
                redirect( clean_request( '', ['action', 'team_id'], FALSE ) );
                break;
            default:
                self::teamDataList();
                break;
        }
    }

    private function teamQueryUser( $teamid = NULL ) {
        $sql_condition = ( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ). 'AND ' : '' ) . "team_id = :teamid" . ( iADMIN ? "" : " AND team_active = :active" );
        $sql_bind = ( iADMIN ? [':teamid' => $teamid] : [':teamid' => $teamid, ':active' => '0'] );
        $result = dbquery( "SELECT a.*, ac.*, tf.*, tu.user_id, tu.user_name, tu.user_status, tu.user_avatar
            FROM " . DB_MYTEAM . " AS a
            LEFT JOIN " . DB_MYTEAM_GROUP . " AS ac ON ac.tgroup_id = a.team_groups
            LEFT JOIN " . DB_MYTEAM_FIELD . " AS tf ON tf.field_teamid = a.team_id
            LEFT JOIN " . DB_USERS . " AS tu ON tu.user_id = a.team_user_id
            " . ( $sql_condition ? "WHERE " . $sql_condition : '' ) . "
            GROUP BY a.team_id
            ORDER BY ac.tgroup_parent ASC, ac.tgroup_id ASC
            ", $sql_bind
        );
        if ( dbrows( $result ) ) {
            $this->teamdata = dbarray( $result );
        } else {
            redirect( FUSION_SELF );
        }
    }

    private function teamUserView( $teamid = NULL ) {
        self::teamQueryUser( $teamid );
        $statuscolor = ( empty( $this->teamdata['team_status'] ) ? "FF4040" : ( $this->teamdata['team_status'] == 1 ? "5CB85C" : "000000" ) );
        $statustitle = ( empty( $this->teamdata['team_status'] ) ? self::$locale['TEAM_038'] : ( $this->teamdata['team_status'] == 1 ? self::$locale['TEAM_037'] : self::$locale['TEAM_039'] ) );
        $status = self::getTeamIcons( 'circle', 'm-l-10', $statustitle, "color:#" . $statuscolor . ";" );
        $userdat = $this->teamdata['team_user_id'] == fusion_get_userdata( 'user_id') ? TRUE : FALSE;
        $edit = ( iADMIN && checkrights( 'TEAM' ) || !empty( $userdat ) ? TRUE : FALSE );
        $alink = $this->teamdata['team_status'] != 1 ? 'publishuser' : 'unpublishuser';
        $activetitle = $this->teamdata['team_status'] != 1 ? self::$locale['TEAM_059'] : self::$locale['TEAM_060'];
        //fieldlist
        foreach ( self::teamFieldList( 1 ) as $id => $field_data ) {
            if ( in_array( $field_data, self::$fieldfile ) ) {
                if ( $id == 'field_email' ) {
                    $iData['field_email'] = ( iADMIN || empty( fusion_get_userdata( 'user_hide_email' ) ) ) ? hide_email( $this->teamdata['field_email'], self::getTeamIcons( 'at', 'm-l-10', self::$locale['UM061a'] ) ) : '';
                } else {
                    $iData[$id] = sprintf( self::$loadField[$id]['show'], $this->teamdata[$id] );
                }
            }
        }
        //end fieldlist
        $info = [
            'avatar'      => self::teamPic( TEAM_TEAM . $this->teamdata['team_pic'] ),
            'real_name'   => $this->teamdata[$this->nametype[$this->teamSettings['team_nametype']]],
            'status'      => $status,
            'position'    => $this->teamdata['team_position'],
            'name'        => !empty( $this->teamdata['team_user_id'] ) ? profile_link( $this->teamdata['user_id'], $this->teamdata['user_name'], $this->teamdata['user_status'] ) : self::$locale['TEAM_E08'],
            'description' => parse_text( $this->teamdata['team_description'], [
                'parse_smileys'        => TRUE,
                'parse_bbcode'         => TRUE,
                'default_image_folder' => NULL,
                'add_line_breaks'      => 'y'
            ] ),
            'profil_link' => [
                'count' => self::getTeamIcons('eye', 'm-r-10') . $this->teamdata['team_count'],
            ] + $iData,
        ];
        if ( $edit ) {
            $info += [
                'admin_link'  => [
                    'useredit'   => "<a href='" . TEAM_PATH . "team.php?action=edituser&amp;team_id=" . $this->teamdata['team_id'] . "'>" . self::getTeamIcons( 'pencil', 'm-l-10 m-r-10', self::$locale['edit'] ) . "</a>",
                    'userdelete' => $this->teamdata['team_active'] ? '' : "<a href='" . TEAM_PATH . "team.php?action=deleteuser&amp;team_id=" . $this->teamdata['team_id'] . "'>" . self::getTeamIcons( 'trash', 'm-l-10 m-r-10', self::$locale['delete'] ) . "</a>",
                    'activelink' => "<a href='" . TEAM_PATH . "team.php?action=" . $alink . "&amp;team_id=" . $this->teamdata['team_id'] . "'>" . self::getTeamIcons( ( $this->teamdata['team_status'] != 1 ? 'usercheck' : 'userslash' ), 'm-l-10', $activetitle ) . "</a>",
                ]
            ];
        }
        teamWievUser( $info );
    }

    private function teamDataList() {
        $sql_bind = [];
        $info['tablename'] = self::$locale['TEAM_002'];
        $info['nouser'] = self::$locale['TEAM_E12'];
        $info['nogroup'] = $this->teamSettings['team_groupuse'];
        $sql_condition = ( multilang_table( "TEAM" ) ? in_group( 'team_language', LANGUAGE ) : '' );

        if ( empty( $this->teamSettings['team_groupuse'] ) ) {
            $info['group'][0] = self::$def_teamgroup;
        }
        if ( !empty( $this->teamSettings['team_groupuse'] ) ) {
            $result = dbquery( $this->sqlTeam->getTeamGroupQuery( ['condition' => "tgroup_status != :status"] ), [':status' => 0] );
            if ( dbrows( $result ) ) {
                while ( $groupdata = dbarray( $result ) ) {
                    $groupdata['tgroup_pic'] = !empty( $groupdata['tgroup_pic'] ) && is_file( TEAM_GROUP . $groupdata['tgroup_pic'] ) ? TEAM_GROUP . $groupdata['tgroup_pic'] : '';
                    $info['group'][$groupdata['tgroup_id']] = $groupdata;
                }
            }
        }

         $result2 = dbquery( "SELECT a.*, ac.*, tf.*, tu.user_id, tu.user_name, tu.user_status, tu.user_avatar
             FROM " . DB_MYTEAM . " AS a
             LEFT JOIN " . DB_MYTEAM_GROUP . " AS ac ON ac.tgroup_id = a.team_groups
             LEFT JOIN " . DB_MYTEAM_FIELD . " AS tf ON tf.field_teamid = a.team_id
             LEFT JOIN " . DB_USERS . " AS tu ON tu.user_id = a.team_user_id
             " . ( $sql_condition ? "WHERE " . $sql_condition : '' ) . "
             GROUP BY a.team_id
             ORDER BY ac.tgroup_parent ASC, ac.tgroup_id ASC
         ");
         if ( dbrows( $result2 ) ) {
             $info['nouser'] = '';
             while ( $team_userdata = dbarray( $result2 ) ) {
                 $t_user = [
                     'avatar'      => "<a href='" . TEAM_PATH . "team.php?action=viewuser&amp;team_id=" . $team_userdata['team_id'] . "'>" . self::teamPic( TEAM_TEAM . $team_userdata['team_pic'],'70') . "</a>",
                     'real_name'   => $team_userdata[$this->nametype[$this->teamSettings['team_nametype']]],
                     'name'        => !empty( $team_userdata['team_user_id'] ) ? profile_link( $team_userdata['user_id'], $team_userdata['user_name'], $team_userdata['user_status'] ) : self::$locale['TEAM_E08'],
                     'count'       => self::getTeamIcons('eye', 'm-r-10') . $team_userdata['team_count'],
                     'description' => parse_text( $team_userdata['team_description'], [
                         'parse_smileys'        => TRUE,
                         'parse_bbcode'         => FALSE,
                         'default_image_folder' => NULL,
                         'add_line_breaks'      => 'y'
                     ] )
                 ];
                 if ( $team_userdata['team_active'] == 1 ) {
                     if ( iADMIN ) {
                         $t_user['enddate'] = showdate( 'Y.m.d', $team_userdata['team_enddate'] );
                         $info['deluser'][] = $t_user;
                     }
                 } else if ( $team_userdata['team_status'] == 1 ) {
                     if ( !empty( $team_userdata['tgroup_status'] ) || !empty( $info['group'][0]['tgroup_status'] ) ) {
                         $groupid = empty( $this->teamSettings['team_groupuse'] ) ? 0 : $team_userdata['team_groups'];
                         $info['group'][$groupid]['team']['active'][] = $t_user;
                     }
                 } else {
                     $t_user['enddate'] = showdate( 'Y.m.d', $team_userdata['team_enddate'] );
                     $info['inactive'][] = $t_user;
                 }
             }
         }
        groupTeamInfo( $info );
    }

    private function teamUserEdit( $teamid = NULL ) {
        self::teamQueryUser( $teamid );
        $userdat = ( $this->teamdata['team_user_id'] == fusion_get_userdata( 'user_id') ) ? TRUE : FALSE;
        $edit = ( iADMIN && checkrights( 'TEAM' ) || !empty( $userdat ) ? TRUE : FALSE );

        //adatbazis
        foreach ( self::teamFieldList( 1 ) as $id => $field_data ) {
            if ( in_array( $field_data, self::$fieldfile ) ) {
                include( TEAM_PATH . 'team_field/' . $field_data . '.php' );
                $field_list[$id] = sprintf( $field[$id]['form'], $this->teamdata[$id] );
            }
        }

        if ( !empty( $edit ) ) {
            if ( check_post( 'save_user' ) ) {
                $iData['field_id'] = sanitizer( 'field_id', '', 'field_id' );
                $iData['field_teamid'] = sanitizer( 'team_id', '', 'team_id' );
                $fields = explode( ',', self::teamFieldList() );
                foreach ( $this->teamdata as $tid => $tdata ) {
                    if ( in_array( $tid, $fields ) ) {
                        $iData[$tid] = sanitizer( $tid, $tdata, $tid );
                    }
                }
                $inputData = [
                    'team_id'          => sanitizer( 'team_id', '', 'team_id' ),
                    'team_user_id'     => sanitizer( 'team_user_id', 0, 'team_user_id' ),
                    'team_real_name'   => sanitizer( 'team_real_name', '', 'team_real_name' ),
                    'team_nickname'    => sanitizer( 'team_nickname', '', 'team_nickname' ),
                    'team_groups'      => sanitizer( 'team_groups', '', 'team_groups' ),
                    'team_position'    => sanitizer( 'team_position', '', 'team_position' ),
                    'team_pic'         => sanitizer( 'team_pic', '', 'team_pic' ),
                    'team_description' => sanitizer( 'team_description', '', 'team_description' ),
                    'team_status'      => sanitizer( 'team_status', 0, 'team_status' ),
                    'team_language'    => sanitizer( 'team_language', LANGUAGE, 'team_language' )
                ];
                if ( fusion_safe() && !empty( $_FILES['team_pic'] ) && is_uploaded_file( $_FILES['team_pic']['tmp_name'] ) ) {
                    $upload = form_sanitizer( $_FILES['team_pic'], '', 'team_pic' );
                    if ( empty( $upload['error'] ) ) {
                        $inputData['team_pic'] = $upload['image_name'];
                    }
                } else if ( check_post( 'del_image' ) && check_post( 'team_id' ) && post( 'team_id', FILTER_VALIDATE_INT ) ) {
                    $result = dbquery("SELECT team_pic FROM " . DB_MYTEAM . " WHERE team_id = :teamid", [':teamid' => post( 'team_id' )] );
                    if ( dbrows( $result ) ) {
                        $data = dbarray( $result );
                        if ( !empty( $data['team_pic'] ) && file_exists( TEAM_TEAM . $data['team_pic'] ) ) {
                            @unlink( TEAM_TEAM . $data['team_pic'] );
                        }
                    }
                    $inputData['team_pic'] = '';
                }
                if ( fusion_safe() ) {
                    $inputData['team_enddate'] = empty( $inputData['team_enddate'] ) && $inputData['team_status'] != 1 ? time() : 0;
                    dbquery_insert( DB_MYTEAM, $inputData, 'update' );
                    dbquery_insert( DB_MYTEAM_FIELD, $iData, 'update' );
                    addnotice( 'success', self::$locale['TEAM_E07'] );
                    redirect( clean_request( '', ['action', 'team_id'], FALSE ) );
                }
            }

            $info = [
                'openform'         => openform( 'groupFrm', 'post', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] ),
                'team_id'          => form_hidden( 'team_id', '', $this->teamdata['team_id'] ),
                'field_id'         => form_hidden( 'field_id', '', $this->teamdata['field_id'] ),
                'team_enddate'     => form_hidden( 'team_enddate', '', $this->teamdata['team_enddate'] ),
                'team_user_id'     => form_select( 'team_user_id', self::$locale['TEAM_030'], $this->teamdata['team_user_id'], [
                    'inline'      => TRUE,
                    'options'     => self::teamUser(),
                    'placeholder' => self::$locale['choose'],
                ] ),
                'team_pic'         => !empty( $this->teamdata['team_pic'] ) ?
                    "<div id='team_user_id-field' class='form-group row'>
                        <label class='control-label col-xs-12 col-sm-12 col-md-3 col-lg-3'>" . self::$locale['TEAM_031'] . "</label>
                        <div class='col-xs-12 col-sm-12 col-md-9 col-lg-9'>
                            <div class='text-left m-r-10'>
                                " . thumbnail( TEAM_TEAM . $this->teamdata['team_pic'], '80px' ) . "
                            </div>
                            <div class='overflow-hide'>
                                " . form_checkbox( 'del_image', self::$locale['delete'], '' ) .
                                form_hidden( 'team_pic', '', $this->teamdata['team_pic'] ) . "
                            </div>
                        </div>
                    </div>" : form_fileinput( 'team_pic', self::$locale['TEAM_031'], '', [
                        'upload_path'     => TEAM_TEAM,
                        'inline'          => TRUE,
                        'multiple'        => FALSE,
                        'delete_original' => FALSE,
                        'template'        => 'modern',
                        'class'           => 'm-b-0',
                        'max_width'       => $this->teamSettings['team_photo_w'],
                        'max_height'      => $this->teamSettings['team_photo_h'],
                        'max_byte'        => $this->teamSettings['team_photo_b'],
                        'ext_tip'         => sprintf( self::$locale['TEAM_032'], parsebytesize( $this->teamSettings['team_photo_b'] ), str_replace( ',', ' ', ".jpg,.gif,.png" ), $this->teamSettings['team_photo_w'], $this->teamSettings['team_photo_h'] )
                ] ),
                'team_real_name'   => form_text( 'team_real_name', self::$locale['TEAM_026'], $this->teamdata['team_real_name'], [
                    'inline'     => TRUE,
                    'required'   => $this->teamSettings['team_nametype'] == 1 ? TRUE : FALSE
                ] ),
                'team_nickname'    => form_text( 'team_nickname', self::$locale['TEAM_027'], $this->teamdata['team_nickname'], [
                    'inline'     => TRUE,
                    'required'   => $this->teamSettings['team_nametype'] == 2 ? TRUE : FALSE
                ] ),
                'team_groups'      => $this->teamSettings['team_groupuse'] ? form_select_tree( 'team_groups', self::$locale['TEAM_033'], $this->teamdata['team_groups'], [
                    'inline'       => TRUE,
                    'parent_value' => self::$locale['choose'],
                ], DB_MYTEAM_GROUP, "tgroup_name", "tgroup_id", "tgroup_parent" )  : form_hidden( 'team_groups', '', $this->teamdata['team_groups'] ),
                'team_position'    => form_text( 'team_position', self::$locale['TEAM_034'], $this->teamdata['team_position'], [
                    'inline'     => TRUE,
                    'required'   => TRUE,
                ] ),
                'team_description' => form_textarea( 'team_description', self::$locale['TEAM_035'], $this->teamdata['team_description'], [
                    'inline'    => TRUE,
                    'html'      => TRUE,
                    'form_name' => 'groupFrm'
                ] ),
                'team_status'      => form_select( 'team_status', self::$locale['TEAM_036'], $this->teamdata['team_status'], [
                    'inline'      => TRUE,
                    'options'     => [1 => self::$locale['TEAM_037'], 0 => self::$locale['TEAM_038'], 2 => self::$locale['TEAM_039']],
                    'placeholder' => self::$locale['choose'],
                ] )
            ] + $field_list;
            $info += [
                'team_language'    => multilang_table( "TEAM" ) ? form_select( 'team_language[]', self::$locale['language'], $this->teamdata['team_language'], [
                    'inline'      => TRUE,
                    'options'     => fusion_get_enabled_languages(),
                    'placeholder' => self::$locale['choose'],
                    'inner_width' => '100%',
                    'multiple'    => TRUE
                ] ) : form_hidden( 'team_language', '', $this->teamdata['team_language'] ),
                'butonsave' => form_button( 'save_user', self::$locale['save'], self::$locale['save'], ['class' => 'btn-sm btn-primary', 'icon' => 'fa fa-floppy-o'] ),
                'closeform' => closeform()
            ];
            groupForm( $info );
        } else {
            redirect( FUSION_SELF );
        }
    }

    public function teamUserDel( $id = NULL ) {
        dbquery( "UPDATE " . DB_MYTEAM . " SET team_active = :active, team_status = :status, team_enddate = :enddate WHERE team_id = :teamid", [':active' => 1, ':status' => 2, ':enddate' => time(), ':teamid' => (int)$id] );
    }
}
