<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: suggestion_submit.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Team;

class TeamSubmit extends TeamServer {
    private static $instance = NULL;
    public $info = [];

    protected function __construct() {
        parent::__construct();
    }

    public static function getInstance() {
        if (self::$instance == NULL) {
            self::$instance = new static();
        }
        return self::$instance;
    }

    public function startTeamSubmit() {
        if ( empty( $this->teamSettings['team_submit' ]) ) {
            redirect( BASEDIR.'index.php' );
        }
        add_to_title(self::$locale['TEAM_070']);
        $info['tablename'] = self::$locale['TEAM_070'];

        if (iMEMBER && $this->teamSettings['team_submit'] && checkgroup( $this->teamSettings['team_submit_access'] ) ) {
            $info += $this->displaySubmissionForm();
        } else {
            $info['no_submit'] = self::$locale['TEAM_E20'];
        }
        teamSubmissions($info);
    }

    private function displaySubmissionForm() {
        $settings = fusion_get_settings();
        // Save
        //adatbazis
        foreach ( self::teamFieldList( 1 ) as $id => $field_data ) {
            if ( in_array( $field_data, self::$fieldfile ) ) {
                self::$def_teamuser[$id] = '';
                $field_list[$id] = sprintf( self::$loadField[$id]['form'], self::$def_teamuser[$id] );
            }
        }
        if ( check_post( 'submit_team' ) ) {
            $criteriaArray = [];
            $fields = explode( ',', self::teamFieldList() );
            foreach ( $fields as $tid => $tdata ) {
                $criteriaArray[$tdata] = sanitizer( $tdata, '', $tdata );
            }
            $criteriaArray += [
                'team_real_name'   => sanitizer( 'team_real_name', '', 'team_real_name' ),
                'team_nickname'    => sanitizer( 'team_nickname', '', 'team_nickname' ),
                'team_pic'         => sanitizer( 'team_pic', '', 'team_pic' ),
                'team_groups'      => sanitizer( 'team_groups', '', 'team_groups' ),
                'team_position'    => sanitizer( 'team_position', '', 'team_position' ),
                'team_description' => sanitizer( 'team_description', '', 'team_description' ),
                'team_language'    => sanitizer( 'team_language', LANGUAGE, 'team_language' )
            ];
            if ( fusion_safe() && !empty( $_FILES['team_pic']['name'] ) && is_uploaded_file( $_FILES['team_pic']['tmp_name'] ) ) {
                $upload = form_sanitizer( $_FILES['team_pic'], '', 'team_pic' );
                if ( empty( $upload['error'] ) ) {
                    $criteriaArray['team_pic'] = $upload['image_name'];
                    unset($upload);
                }
            }
            if ( fusion_safe() ) {
                $inputArray = [
                    'submit_type'      => 't',
                    'submit_user'      => fusion_get_userdata( 'user_id' ),
                    'submit_datestamp' => time(),
                    'submit_criteria'  => \Defender::encode( $criteriaArray )
                ];
                dbquery_insert( DB_SUBMISSIONS, $inputArray, 'save' );
                addnotice( 'success', self::$locale['TEAM_E21'] );
                redirect( clean_request( 'submitted=t', ['stype'], TRUE ) );
            }
        }

        if ( check_get( 'submitted' ) && get( 'submitted' ) == "t" ) {
            $info['confirm'] = [
                'title'       => self::$locale['TEAM_E22'],
                'index_link'  => "<a href='" . BASEDIR . $settings['opening_page'] . "'>" . str_replace( "[SITENAME]", $settings['sitename'], self::$locale['TEAM_071'] ) . "</a>"
            ];
        } else {
            $info['guidelines'] = self::$locale['TEAM_072'];
            $info['submit'] = [
                'openform'         => openform( 'teamsubmitform', 'POST', FUSION_REQUEST, ['enctype' => TRUE, 'class' => 'm-t-20'] ),
                'team_real_name'   => form_text( 'team_real_name', self::$locale['TEAM_026'], '', [
                    'inline'      => TRUE,
                    'required'    => $this->teamSettings['team_nametype'] == 1 ? TRUE : FALSE,
                    'placeholder' => self::$locale['TEAM_026']
                ] ),
                'team_nickname'   => form_text( 'team_nickname', self::$locale['TEAM_027'], '', [
                    'inline'      => TRUE,
                    'required'    => $this->teamSettings['team_nametype'] == 2 ? TRUE : FALSE,
                    'placeholder' => self::$locale['TEAM_027']
                ] ),
                'team_pic'         => form_fileinput( 'team_pic', self::$locale['TEAM_031'], '', [
                    'upload_path'     => TEAM_PATH . 'submissions/',
                    'inline'          => TRUE,
                    'multiple'        => FALSE,
                    'delete_original' => FALSE,
                    'type'            => "image",
                    'template'        => 'modern',
                    'class'           => 'm-b-0',
                    'max_width'       => $this->teamSettings['team_photo_w'],
                    'max_height'      => $this->teamSettings['team_photo_h'],
                    'max_byte'        => $this->teamSettings['team_photo_b'],
                    'ext_tip'         => sprintf( self::$locale['TEAM_032'], parsebytesize( $this->teamSettings['team_photo_b'] ), str_replace( ',', ' ', ".jpg,.gif,.png" ), $this->teamSettings['team_photo_w'], $this->teamSettings['team_photo_h'] )
                ] ),
                'team_groups'      => form_select_tree( 'team_groups', self::$locale['TEAM_033'], 0, [
                    'inline'       => TRUE,
                    'parent_value' => self::$locale['choose'],
                ], DB_MYTEAM_GROUP, "tgroup_name", "tgroup_id", "tgroup_parent" ),
                'team_position'    => form_text( 'team_position', self::$locale['TEAM_034'], '', [
                    'inline'      => TRUE,
                    'required'    => TRUE,
                    'placeholder' => self::$locale['TEAM_034']
                ] ),
                'team_description' => form_textarea( 'team_description', self::$locale['TEAM_035'], '', [
                    'inline'    => TRUE,
                    'html'      => TRUE,
                    'form_name' => 'teamsubmitform'
                ] ),
            ] + $field_list;
            $info['submit'] += [
                'team_language'    => multilang_table( "TEAM" ) ? form_select( 'team_language[]', self::$locale['language'], LANGUAGE, [
                    'inline'      => TRUE,
                    'options'     => fusion_get_enabled_languages(),
                    'placeholder' => self::$locale['choose'],
                    'inner_width' => '100%',
                    'multiple'    => TRUE
                ] ) : form_hidden( 'team_language', '', LANGUAGE ),
                'button'           => form_button( 'submit_team', self::$locale['submit'], self::$locale['submit'], ['class' => 'btn-primary'] ),
                'closeform'        => closeform()
            ];
        }
        return $info;
    }
}
